@@ -114,35 +114,36 @@
         }                                                             \
     }
 
-#define NVSHMEMI_TEAM_INITIALIZER                                                                 \
-    {                                                                                             \
-        (2 << 16) + sizeof(nvshmemi_team_t),                       /* version */                  \
-            TEAM_SCALAR_INVALID,                                   /* my_pe */                    \
-            TEAM_SCALAR_INVALID,                                   /* start */                    \
-            TEAM_SCALAR_INVALID,                                   /* stride */                   \
-            TEAM_SCALAR_INVALID,                                   /* size */                     \
-            TEAM_SCALAR_INVALID,                                   /* team_idx */                 \
-            NVSHMEMI_TEAM_CONFIG_INITIALIZER, TEAM_SCALAR_INVALID, /* config_mask */              \
-            NULL,                                                  /* nccl_comm */                \
-            NVSHMEMI_RED_REX_INITIALIZER, TEAM_ULSCALAR_INVALID,   /* rdxn_count */               \
-            TEAM_USCALAR_INVALID,                                  /* ll_flag */                  \
-            TEAM_ULSCALAR_DEFAULT,                                 /* alltoall_pwrk[0] */         \
-            TEAM_ULSCALAR_DEFAULT,                                 /* alltoall_pwrk[1] */         \
-            TEAM_ULSCALAR_DEFAULT,                                 /* alltoall_count */           \
-            TEAM_ULSCALAR_INVALID,                                 /* bcast_count */              \
-            TEAM_ULSCALAR_INVALID,                                 /* bcast_sync_offset */        \
-            TEAM_ULSCALAR_INVALID,                                 /* fcollect_count */           \
-            TEAM_USCALAR_INVALID,                                  /* fcollect_ll_flag */         \
-            false,                                                 /* are_gpus_p2p_connected */   \
-            false,                                                 /* is_team_node */             \
-            TEAM_SCALAR_INVALID,                                   /* team_node */                \
-            false,                                                 /* is_team_same_mype_node */   \
-            TEAM_SCALAR_INVALID,                                   /* team_same_mype_node */      \
-            NULL,                                                  /* nvls_rsc */                 \
-            NULL,                                                  /* nvls_rsc_base_ptr */        \
-            {TEAM_SCALAR_INVALID},                                 /* team_dups */                \
+#define NVSHMEMI_TEAM_V4_IDENTIFIER ((4 << 16) + sizeof(nvshmemi_team_t))
+#define NVSHMEMI_TEAM_INITIALIZER                                                               \
+    {                                                                                           \
+        NVSHMEMI_TEAM_V4_IDENTIFIER,                               /* version */                \
+            TEAM_SCALAR_INVALID,                                   /* my_pe */                  \
+            TEAM_SCALAR_INVALID,                                   /* start */                  \
+            TEAM_SCALAR_INVALID,                                   /* stride */                 \
+            TEAM_SCALAR_INVALID,                                   /* size */                   \
+            TEAM_SCALAR_INVALID,                                   /* team_idx */               \
+            NVSHMEMI_TEAM_CONFIG_INITIALIZER, TEAM_SCALAR_INVALID, /* config_mask */            \
+            NULL,                                                  /* nccl_comm */              \
+            NVSHMEMI_RED_REX_INITIALIZER, TEAM_ULSCALAR_INVALID,   /* rdxn_count */             \
+            TEAM_USCALAR_INVALID,                                  /* ll_flag */                \
+            TEAM_ULSCALAR_DEFAULT,                                 /* alltoall_pwrk[0] */       \
+            TEAM_ULSCALAR_DEFAULT,                                 /* alltoall_pwrk[1] */       \
+            TEAM_ULSCALAR_DEFAULT,                                 /* alltoall_count */         \
+            TEAM_ULSCALAR_INVALID,                                 /* bcast_count */            \
+            TEAM_ULSCALAR_INVALID,                                 /* bcast_sync_offset */      \
+            TEAM_ULSCALAR_INVALID,                                 /* fcollect_count */         \
+            TEAM_USCALAR_INVALID,                                  /* fcollect_ll_flag */       \
+            false,                                                 /* are_gpus_p2p_connected */ \
+            false,                                                 /* is_team_node */           \
+            TEAM_SCALAR_INVALID,                                   /* team_node */              \
+            false,                                                 /* is_team_same_mype_node */ \
+            TEAM_SCALAR_INVALID,                                   /* team_same_mype_node */    \
+            NULL,                                                  /* nvls_rsc */               \
+            NULL,                                                  /* nvls_rsc_base_ptr */      \
+            {TEAM_SCALAR_INVALID},                                 /* team_dups */              \
+            NULL,                                                  /* pe_mapping */             \
             TEAM_ULSCALAR_INVALID,                                 /* p2p_sync_on_stream_count */ \
-            NULL,                                                  /* pe_mapping */               \
     }
 
 #define NVSHMEMI_GPU_COLL_PARAMS_INITIALIZER                                          \
@@ -335,11 +336,37 @@ typedef struct {
     void *nvls_rsc;          /* To be cast to nvshmemi_nvls_rsc whenever used */
     void *nvls_rsc_base_ptr; /* Shared b/w GPU threads of this team */
     nvshmem_team_t team_dups[128];
+    int *pe_mapping; /* Pointer to the PE mapping array allocated after the struct */
     uint64_t p2p_sync_on_stream_count;
-    int *pe_mapping; /* Pointer to the PE mapping array allocated after the struct
-                      This must be the last field in the struct. Any new fields will need
-                      to come before it and will require additional logic in the internal team
-                      code to handle the version differences. */
+} nvshmemi_team_v4;
+
+typedef struct {
+    int version;
+    int my_pe;
+    int start, stride, size;
+    int team_idx;
+    nvshmem_team_config_t config;
+    long config_mask;
+    void *nccl_comm; /* To be cast to ncclComm_t whenever used */
+    nvshmemi_reduce_recexch_t reduce_recexch;
+    size_t rdxn_count;
+    uint32_t ll_flag;
+    uint64_t alltoall_pwrk[2];
+    uint64_t alltoall_count;
+    uint64_t bcast_count;
+    uint64_t bcast_sync_offset;
+    uint64_t fcollect_count;
+    uint32_t fcollect_ll_flag;
+    bool are_gpus_p2p_connected;
+    bool is_team_node; /* If set to true, 'team_node' refers to rsvd NVSHMEMX_TEAM_NODE */
+    nvshmem_team_t team_node;
+    bool is_team_same_mype_node; /* If set to true, 'team_same_mype_node' refers to rsvd
+                                    NVSHMEMX_TEAM_SAME_MYPE_NODE */
+    nvshmem_team_t team_same_mype_node;
+    void *nvls_rsc;          /* To be cast to nvshmemi_nvls_rsc whenever used */
+    void *nvls_rsc_base_ptr; /* Shared b/w GPU threads of this team */
+    nvshmem_team_t team_dups[128];
+    int *pe_mapping; /* Pointer to the PE mapping array allocated after the struct */
 } nvshmemi_team_v3;
 
 typedef struct {
@@ -394,11 +421,12 @@ typedef struct {
                                     NVSHMEMX_TEAM_SAME_MYPE_NODE */
     nvshmem_team_t team_same_mype_node;
 } nvshmemi_team_v1;
-static_assert(sizeof(nvshmemi_team_v1) == 256, "team_v1 must be 256 bytes.");
+static_assert(sizeof(nvshmemi_team_v4) == 800, "team_v4 must be 800 bytes.");
+static_assert(sizeof(nvshmemi_team_v3) == 792, "team_v3 must be 792 bytes.");
 static_assert(sizeof(nvshmemi_team_v2) == 784, "team_v2 must be 784 bytes.");
-static_assert(sizeof(nvshmemi_team_v3) == 800, "team_v3 must be 800 bytes.");
+static_assert(sizeof(nvshmemi_team_v1) == 256, "team_v1 must be 256 bytes.");
 
-typedef nvshmemi_team_v3 nvshmemi_team_t;
+typedef nvshmemi_team_v4 nvshmemi_team_t;
 
 typedef struct {
     int version;
